@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_ENABLEJOB_H
-#define KIMAP_ENABLEJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -58,5 +57,3 @@ protected:
 };
 
 }
-
-#endif
